import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPRemoteCommandEvent(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertEqual(MediaPlayer.MPSeekCommandEventTypeBeginSeeking, 0)
            self.assertEqual(MediaPlayer.MPSeekCommandEventTypeEndSeeking, 1)

        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(MediaPlayer.MPFeedbackCommandEvent.isNegative)
            self.assertResultIsBOOL(
                MediaPlayer.MPChangeShuffleModeCommandEvent.preservesShuffleMode
            )
            self.assertResultIsBOOL(
                MediaPlayer.MPChangeRepeatModeCommandEvent.preservesRepeatMode
            )



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPNowPlayingInfoLanguageOption(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicIsMainProgramContent, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicIsAuxiliaryContent, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicContainsOnlyForcedSubtitles,
                str,
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicTranscribesSpokenDialog, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicDescribesMusicAndSound, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicEasyToRead, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicDescribesVideo, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicLanguageTranslation, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicDubbedTranslation, str
            )
            self.assertIsInstance(
                MediaPlayer.MPLanguageOptionCharacteristicVoiceOverTranslation, str
            )

            self.assertEqual(MediaPlayer.MPNowPlayingInfoLanguageOptionTypeAudible, 0)
            self.assertEqual(MediaPlayer.MPNowPlayingInfoLanguageOptionTypeLegible, 1)

        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(
                MediaPlayer.MPNowPlayingInfoLanguageOption.isAutomaticLegibleLanguageOption
            )
            self.assertResultIsBOOL(
                MediaPlayer.MPNowPlayingInfoLanguageOption.isAutomaticAudibleLanguageOption
            )

            self.assertArgIsBOOL(
                MediaPlayer.MPNowPlayingInfoLanguageOptionGroup.initWithLanguageOptions_defaultLanguageOption_allowEmptySelection_,  # noqa: B950
                2,
            )
            self.assertResultIsBOOL(
                MediaPlayer.MPNowPlayingInfoLanguageOptionGroup.allowEmptySelection
            )



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPError(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertIsInstance(MediaPlayer.MPErrorDomain, str)

            self.assertEqual(MediaPlayer.MPErrorUnknown, 0)
            self.assertEqual(MediaPlayer.MPErrorPermissionDenied, 1)
            self.assertEqual(MediaPlayer.MPErrorCloudServiceCapabilityMissing, 2)
            self.assertEqual(MediaPlayer.MPErrorNetworkConnectionFailed, 3)
            self.assertEqual(MediaPlayer.MPErrorNotFound, 4)
            self.assertEqual(MediaPlayer.MPErrorNotSupported, 5)
            self.assertEqual(MediaPlayer.MPErrorCancelled, 6)
            self.assertEqual(MediaPlayer.MPErrorRequestTimedOut, 7)



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import (
        TestCase,
        min_os_level,
        os_level_key,
        os_release,
        expectedFailureIf,
    )
    import MediaPlayer

    class TestMPNowPlayingInfoCenter(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertEqual(MediaPlayer.MPNowPlayingInfoMediaTypeNone, 0)
            self.assertEqual(MediaPlayer.MPNowPlayingInfoMediaTypeAudio, 1)
            self.assertEqual(MediaPlayer.MPNowPlayingInfoMediaTypeVideo, 2)
            self.assertEqual(MediaPlayer.MPNowPlayingPlaybackStateUnknown, 0)
            self.assertEqual(MediaPlayer.MPNowPlayingPlaybackStatePlaying, 1)
            self.assertEqual(MediaPlayer.MPNowPlayingPlaybackStatePaused, 2)
            self.assertEqual(MediaPlayer.MPNowPlayingPlaybackStateStopped, 3)
            self.assertEqual(MediaPlayer.MPNowPlayingPlaybackStateInterrupted, 4)

            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyElapsedPlaybackTime, str
            )
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoPropertyPlaybackRate, str)
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyDefaultPlaybackRate, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyPlaybackQueueIndex, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyPlaybackQueueCount, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyChapterNumber, str
            )
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoPropertyChapterCount, str)
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoPropertyIsLiveStream, str)
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyAvailableLanguageOptions, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyCurrentLanguageOptions, str
            )
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoCollectionIdentifier, str)
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyExternalContentIdentifier, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyExternalUserProfileIdentifier, str
            )
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyPlaybackProgress, str
            )
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoPropertyMediaType, str)
            self.assertIsInstance(MediaPlayer.MPNowPlayingInfoPropertyAssetURL, str)

        @min_os_level("10.13")
        @expectedFailureIf(
            os_level_key(os_release()) < os_level_key("10.14")
        )  # Documented for 10.13, but doesn't work there
        def testConstants10_13(self):
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyServiceIdentifier, str
            )

        @min_os_level("10.13.1")
        def testConstants10_13_1(self):
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyCurrentPlaybackDate, str
            )



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPRemoteControlTypes(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertEqual(MediaPlayer.MPShuffleTypeOff, 0)
            self.assertEqual(MediaPlayer.MPShuffleTypeItems, 1)
            self.assertEqual(MediaPlayer.MPShuffleTypeCollections, 2)
            self.assertEqual(MediaPlayer.MPRepeatTypeOff, 0)
            self.assertEqual(MediaPlayer.MPRepeatTypeOne, 1)
            self.assertEqual(MediaPlayer.MPRepeatTypeAll, 2)
            self.assertEqual(MediaPlayer.MPChangeLanguageOptionSettingNone, 0)
            self.assertEqual(
                MediaPlayer.MPChangeLanguageOptionSettingNowPlayingItemOnly, 1
            )
            self.assertEqual(MediaPlayer.MPChangeLanguageOptionSettingPermanent, 2)



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer
    import Quartz

    class TestMPMediaItem(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertEqual(MediaPlayer.MPMediaTypeMusic, 1 << 0)
            self.assertEqual(MediaPlayer.MPMediaTypePodcast, 1 << 1)
            self.assertEqual(MediaPlayer.MPMediaTypeAudioBook, 1 << 2)
            self.assertEqual(MediaPlayer.MPMediaTypeAudioITunesU, 1 << 3)
            self.assertEqual(MediaPlayer.MPMediaTypeAnyAudio, 0x00FF)
            self.assertEqual(MediaPlayer.MPMediaTypeMovie, 1 << 8)
            self.assertEqual(MediaPlayer.MPMediaTypeTVShow, 1 << 9)
            self.assertEqual(MediaPlayer.MPMediaTypeVideoPodcast, 1 << 10)
            self.assertEqual(MediaPlayer.MPMediaTypeMusicVideo, 1 << 11)
            self.assertEqual(MediaPlayer.MPMediaTypeVideoITunesU, 1 << 12)
            self.assertEqual(MediaPlayer.MPMediaTypeHomeVideo, 1 << 13)
            self.assertEqual(MediaPlayer.MPMediaTypeAnyVideo, 0xFF00)

            self.assertEqual(MediaPlayer.MPMediaTypeAny, 0xFFFFFFFFFFFFFFFF)

            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyPersistentID, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyMediaType, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyTitle, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAlbumTitle, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAlbumPersistentID, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyArtist, str)
            self.assertIsInstance(
                MediaPlayer.MPMediaItemPropertyArtistPersistentID, str
            )
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAlbumArtist, str)
            self.assertIsInstance(
                MediaPlayer.MPMediaItemPropertyAlbumArtistPersistentID, str
            )
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyGenre, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyGenrePersistentID, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyComposer, str)
            self.assertIsInstance(
                MediaPlayer.MPMediaItemPropertyComposerPersistentID, str
            )
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyPlaybackDuration, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAlbumTrackNumber, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAlbumTrackCount, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyDiscNumber, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyDiscCount, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyArtwork, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyIsExplicit, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyLyrics, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyReleaseDate, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyBeatsPerMinute, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyComments, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyAssetURL, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyIsCloudItem, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyHasProtectedAsset, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyPodcastTitle, str)
            self.assertIsInstance(
                MediaPlayer.MPMediaItemPropertyPodcastPersistentID, str
            )
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyPlayCount, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertySkipCount, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyRating, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyLastPlayedDate, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyUserGrouping, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyBookmarkTime, str)
            self.assertIsInstance(MediaPlayer.MPMediaItemPropertyDateAdded, str)

        @min_os_level("10.13.1")
        def testConstants10_13(self):
            self.assertIsInstance(
                MediaPlayer.MPNowPlayingInfoPropertyCurrentPlaybackDate, str
            )

        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(MediaPlayer.MPMediaItem.isExplicitItem)
            self.assertResultIsBOOL(MediaPlayer.MPMediaItem.isCompilation)
            self.assertResultIsBOOL(MediaPlayer.MPMediaItem.isCloudItem)
            self.assertResultIsBOOL(MediaPlayer.MPMediaItem.hasProtectedAsset)

            self.assertArgIsBlock(
                MediaPlayer.MPMediaItemArtwork.initWithBoundsSize_requestHandler_,
                1,
                b"@" + Quartz.CGSize.__typestr__,
            )



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPPlayableContentManagerContext(TestCase):
        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(
                MediaPlayer.MPPlayableContentManagerContext.contentLimitsEnforced
            )
            self.assertResultIsBOOL(
                MediaPlayer.MPPlayableContentManagerContext.contentLimitsEnabled
            )
            self.assertResultIsBOOL(
                MediaPlayer.MPPlayableContentManagerContext.endpointAvailable
            )



"""
Python mapping for the MediaPlayer framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import AVFoundation
import objc
from MediaPlayer import _metadata

sys.modules["MediaPlayer"] = mod = objc.ObjCLazyModule(
    "MediaPlayer",
    "com.apple.MediaPlayer",
    objc.pathForFramework("/System/Library/Frameworks/MediaPlayer.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (AVFoundation,),
)


del sys.modules["MediaPlayer._metadata"]



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPMediaEntity(TestCase):
        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(MediaPlayer.MPMediaEntity.canFilterByProperty_)

            self.assertArgIsBlock(
                MediaPlayer.MPMediaEntity.enumerateValuesForProperties_usingBlock_,
                1,
                b"v@@o^Z",
            )

        @min_os_level("10.12")
        def testConstants(self):
            self.assertIsInstance(MediaPlayer.MPMediaEntityPropertyPersistentID, str)



# This file is generated by objective.metadata
#
# Last update: Mon Mar 16 21:42:37 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$MPErrorDomain$MPLanguageOptionCharacteristicContainsOnlyForcedSubtitles$MPLanguageOptionCharacteristicDescribesMusicAndSound$MPLanguageOptionCharacteristicDescribesVideo$MPLanguageOptionCharacteristicDubbedTranslation$MPLanguageOptionCharacteristicEasyToRead$MPLanguageOptionCharacteristicIsAuxiliaryContent$MPLanguageOptionCharacteristicIsMainProgramContent$MPLanguageOptionCharacteristicLanguageTranslation$MPLanguageOptionCharacteristicTranscribesSpokenDialog$MPLanguageOptionCharacteristicVoiceOverTranslation$MPMediaEntityPropertyPersistentID$MPMediaItemPropertyAlbumArtist$MPMediaItemPropertyAlbumArtistPersistentID$MPMediaItemPropertyAlbumPersistentID$MPMediaItemPropertyAlbumTitle$MPMediaItemPropertyAlbumTrackCount$MPMediaItemPropertyAlbumTrackNumber$MPMediaItemPropertyArtist$MPMediaItemPropertyArtistPersistentID$MPMediaItemPropertyArtwork$MPMediaItemPropertyAssetURL$MPMediaItemPropertyBeatsPerMinute$MPMediaItemPropertyBookmarkTime$MPMediaItemPropertyComments$MPMediaItemPropertyComposer$MPMediaItemPropertyComposerPersistentID$MPMediaItemPropertyDateAdded$MPMediaItemPropertyDiscCount$MPMediaItemPropertyDiscNumber$MPMediaItemPropertyGenre$MPMediaItemPropertyGenrePersistentID$MPMediaItemPropertyHasProtectedAsset$MPMediaItemPropertyIsCloudItem$MPMediaItemPropertyIsCompilation$MPMediaItemPropertyIsExplicit$MPMediaItemPropertyLastPlayedDate$MPMediaItemPropertyLyrics$MPMediaItemPropertyMediaType$MPMediaItemPropertyPersistentID$MPMediaItemPropertyPlayCount$MPMediaItemPropertyPlaybackDuration$MPMediaItemPropertyPlaybackStoreID$MPMediaItemPropertyPodcastPersistentID$MPMediaItemPropertyPodcastTitle$MPMediaItemPropertyRating$MPMediaItemPropertyReleaseDate$MPMediaItemPropertySkipCount$MPMediaItemPropertyTitle$MPMediaItemPropertyUserGrouping$MPNowPlayingInfoCollectionIdentifier$MPNowPlayingInfoPropertyAssetURL$MPNowPlayingInfoPropertyAvailableLanguageOptions$MPNowPlayingInfoPropertyChapterCount$MPNowPlayingInfoPropertyChapterNumber$MPNowPlayingInfoPropertyCurrentLanguageOptions$MPNowPlayingInfoPropertyCurrentPlaybackDate$MPNowPlayingInfoPropertyDefaultPlaybackRate$MPNowPlayingInfoPropertyElapsedPlaybackTime$MPNowPlayingInfoPropertyExternalContentIdentifier$MPNowPlayingInfoPropertyExternalUserProfileIdentifier$MPNowPlayingInfoPropertyIsLiveStream$MPNowPlayingInfoPropertyMediaType$MPNowPlayingInfoPropertyPlaybackProgress$MPNowPlayingInfoPropertyPlaybackQueueCount$MPNowPlayingInfoPropertyPlaybackQueueIndex$MPNowPlayingInfoPropertyPlaybackRate$MPNowPlayingInfoPropertyServiceIdentifier$MPNowPlayingInfoPropertyServiceIdentifier,$"""
enums = """$MPChangeLanguageOptionSettingNone@0$MPChangeLanguageOptionSettingNowPlayingItemOnly@1$MPChangeLanguageOptionSettingPermanent@2$MPErrorCancelled@6$MPErrorCloudServiceCapabilityMissing@2$MPErrorNetworkConnectionFailed@3$MPErrorNotFound@4$MPErrorNotSupported@5$MPErrorPermissionDenied@1$MPErrorRequestTimedOut@7$MPErrorUnknown@0$MPMediaTypeAny@18446744073709551615$MPMediaTypeAnyAudio@255$MPMediaTypeAnyVideo@65280$MPMediaTypeAudioBook@4$MPMediaTypeAudioITunesU@8$MPMediaTypeHomeVideo@8192$MPMediaTypeMovie@256$MPMediaTypeMusic@1$MPMediaTypeMusicVideo@2048$MPMediaTypePodcast@2$MPMediaTypeTVShow@512$MPMediaTypeVideoITunesU@4096$MPMediaTypeVideoPodcast@1024$MPNowPlayingInfoLanguageOptionTypeAudible@0$MPNowPlayingInfoLanguageOptionTypeLegible@1$MPNowPlayingInfoMediaTypeAudio@1$MPNowPlayingInfoMediaTypeNone@0$MPNowPlayingInfoMediaTypeVideo@2$MPNowPlayingPlaybackStateInterrupted@4$MPNowPlayingPlaybackStatePaused@2$MPNowPlayingPlaybackStatePlaying@1$MPNowPlayingPlaybackStateStopped@3$MPNowPlayingPlaybackStateUnknown@0$MPRemoteCommandHandlerStatusCommandFailed@200$MPRemoteCommandHandlerStatusDeviceNotFound@120$MPRemoteCommandHandlerStatusNoActionableNowPlayingItem@110$MPRemoteCommandHandlerStatusNoSuchContent@100$MPRemoteCommandHandlerStatusSuccess@0$MPRepeatTypeAll@2$MPRepeatTypeOff@0$MPRepeatTypeOne@1$MPSeekCommandEventTypeBeginSeeking@0$MPSeekCommandEventTypeEndSeeking@1$MPShuffleTypeCollections@2$MPShuffleTypeItems@1$MPShuffleTypeOff@0$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"MPChangeRepeatModeCommandEvent",
        b"preservesRepeatMode",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPChangeRepeatModeCommandEvent",
        b"setPreservesRepeatMode:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"MPChangeShuffleModeCommandEvent",
        b"preservesShuffleMode",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPChangeShuffleModeCommandEvent",
        b"setPreservesShuffleMode:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"MPContentItem", b"isContainer", {"retval": {"type": "Z"}})
    r(b"MPContentItem", b"isExplicitContent", {"retval": {"type": "Z"}})
    r(b"MPContentItem", b"isPlayable", {"retval": {"type": "Z"}})
    r(b"MPContentItem", b"isStreamingContent", {"retval": {"type": "Z"}})
    r(b"MPContentItem", b"setContainer:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPContentItem", b"setExplicitContent:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPContentItem", b"setPlayable:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPContentItem", b"setStreamingContent:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPFeedbackCommand", b"isActive", {"retval": {"type": "Z"}})
    r(b"MPFeedbackCommand", b"setActive:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPFeedbackCommandEvent", b"isNegative", {"retval": {"type": "Z"}})
    r(b"MPFeedbackCommandEvent", b"setNegative:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPMediaEntity", b"canFilterByProperty:", {"retval": {"type": "Z"}})
    r(
        b"MPMediaEntity",
        b"enumerateValuesForProperties:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"MPMediaEntity",
        b"enumerateValuesForProperties:usingBlock::",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(b"MPMediaItem", b"hasProtectedAsset", {"retval": {"type": "Z"}})
    r(b"MPMediaItem", b"isCloudItem", {"retval": {"type": "Z"}})
    r(b"MPMediaItem", b"isCompilation", {"retval": {"type": "Z"}})
    r(b"MPMediaItem", b"isExplicitItem", {"retval": {"type": "Z"}})
    r(b"MPMediaItem", b"setCloudItem:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPMediaItem", b"setCompilation:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPMediaItem", b"setExplicitItem:", {"arguments": {2: {"type": "Z"}}})
    r(b"MPMediaItem", b"setHasProtectedAsset:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"MPMediaItemArtwork",
        b"initWithBoundsSize:requestHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": sel32or64(b"{CGSize=ff}", b"{CGSize=dd}")},
                        },
                    }
                }
            }
        },
    )
    r(
        b"MPNowPlayingInfoLanguageOption",
        b"isAutomaticAudibleLanguageOption",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPNowPlayingInfoLanguageOption",
        b"isAutomaticLegibleLanguageOption",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPNowPlayingInfoLanguageOptionGroup",
        b"allowEmptySelection",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPNowPlayingInfoLanguageOptionGroup",
        b"initWithLanguageOptions:defaultLanguageOption:allowEmptySelection:",
        {"arguments": {4: {"type": "Z"}}},
    )
    r(
        b"MPNowPlayingInfoLanguageOptionGroup",
        b"setAllowEmptySelection:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"contentLimitsEnabled",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"contentLimitsEnforced",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"endpointAvailable",
        {"retval": {"type": "Z"}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"setContentLimitsEnabled:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"setContentLimitsEnforced:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"MPPlayableContentManagerContext",
        b"setEndpointAvailable:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"MPRemoteCommand",
        b"addTargetWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": sel32or64(b"i", b"q")},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"MPRemoteCommand", b"isEnabled", {"retval": {"type": "Z"}})
    r(b"MPRemoteCommand", b"setEnabled:", {"arguments": {2: {"type": "Z"}}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer
    import objc

    class TestMPRemoteCommand(TestCase):
        @min_os_level("10.12")
        def testConstants(self):
            self.assertEqual(MediaPlayer.MPRemoteCommandHandlerStatusSuccess, 0)
            self.assertEqual(MediaPlayer.MPRemoteCommandHandlerStatusNoSuchContent, 100)
            self.assertEqual(
                MediaPlayer.MPRemoteCommandHandlerStatusNoActionableNowPlayingItem, 110
            )
            self.assertEqual(
                MediaPlayer.MPRemoteCommandHandlerStatusDeviceNotFound, 120
            )
            self.assertEqual(MediaPlayer.MPRemoteCommandHandlerStatusCommandFailed, 200)

        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(MediaPlayer.MPRemoteCommand.isEnabled)
            self.assertArgIsBOOL(MediaPlayer.MPRemoteCommand.setEnabled_, 0)

            self.assertArgIsBlock(
                MediaPlayer.MPRemoteCommand.addTargetWithHandler_,
                0,
                objc._C_NSInteger + b"@",
            )

            self.assertResultIsBOOL(MediaPlayer.MPFeedbackCommand.isActive)
            self.assertArgIsBOOL(MediaPlayer.MPFeedbackCommand.setActive_, 0)



import sys


if sys.maxsize > 2 ** 32:
    from PyObjCTools.TestSupport import TestCase, min_os_level
    import MediaPlayer

    class TestMPContentItem(TestCase):
        @min_os_level("10.12")
        def testMethods(self):
            self.assertResultIsBOOL(MediaPlayer.MPContentItem.isContainer)
            self.assertArgIsBOOL(MediaPlayer.MPContentItem.setContainer_, 0)

            self.assertResultIsBOOL(MediaPlayer.MPContentItem.isPlayable)
            self.assertArgIsBOOL(MediaPlayer.MPContentItem.setPlayable_, 0)

            self.assertResultIsBOOL(MediaPlayer.MPContentItem.isStreamingContent)
            self.assertArgIsBOOL(MediaPlayer.MPContentItem.setStreamingContent_, 0)

            self.assertResultIsBOOL(MediaPlayer.MPContentItem.isExplicitContent)
            self.assertArgIsBOOL(MediaPlayer.MPContentItem.setExplicitContent_, 0)
